==> jc-1.4.0.tar.gz: soot/grimp/internal/GMulExpr.h <==
// public class soot.grimp.internal.GMulExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d1552223b1338ef5 soot_grimp_internal_AbstractGrimpFloatBinopExpr
// @dep_class 2d323bdcaaea72de soot_grimp_internal_GMulExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b3123b7fa425fe58 soot_jimple_internal_AbstractFloatBinopExpr

// header file dependencies
// @dep_header soot_grimp_internal_AbstractGrimpFloatBinopExpr

#include "soot/grimp/internal/AbstractGrimpFloatBinopExpr.h"

#ifndef _JC_soot_grimp_internal_GMulExpr_H_
#define _JC_soot_grimp_internal_GMulExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GMulExpr$sub_refs	_jc_soot_grimp_internal_GMulExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GMulExpr$sub_nonrefs	_jc_soot_grimp_internal_GMulExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GMulExpr$refs	_jc_soot_grimp_internal_GMulExpr$refs;
typedef struct _jc_soot_grimp_internal_GMulExpr$nonrefs	_jc_soot_grimp_internal_GMulExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GMulExpr$object	_jc_soot_grimp_internal_GMulExpr$object;

typedef const struct _jc_soot_grimp_internal_GMulExpr$vmethods	_jc_soot_grimp_internal_GMulExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GMulExpr$vtable	_jc_soot_grimp_internal_GMulExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GMulExpr$vtype	_jc_soot_grimp_internal_GMulExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GMulExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_grimp_internal_GMulExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GMulExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *);
extern jint _jc_soot_grimp_internal_GMulExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GMulExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GMulExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GMulExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GMulExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GMulExpr$method_info$getSymbol$ce407d9fb7da8b41;

// Virtual methods structure
struct _jc_soot_grimp_internal_GMulExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GMulExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	soot_jimple_internal_AbstractFloatBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
	_jc_soot_grimp_internal_GMulExpr$vmethods	soot_grimp_internal_GMulExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GMulExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GMulExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GMulExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GMulExpr$refs {
    _jc_soot_grimp_internal_GMulExpr$sub_refs	soot_grimp_internal_GMulExpr;
    _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GMulExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GMulExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
    _jc_soot_grimp_internal_GMulExpr$sub_nonrefs	soot_grimp_internal_GMulExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GMulExpr$object {
	_jc_soot_grimp_internal_GMulExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GMulExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GMulExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GMulExpr$vtype _jc_soot_grimp_internal_GMulExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GMulExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GMulExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GMulExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GMulExpr.h <==
// public class soot.grimp.internal.GMulExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d1552223b1338ef5 soot_grimp_internal_AbstractGrimpFloatBinopExpr
// @dep_class 2d323bdcaaea72de soot_grimp_internal_GMulExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b3123b7fa425fe58 soot_jimple_internal_AbstractFloatBinopExpr

// header file dependencies
// @dep_header soot_grimp_internal_AbstractGrimpFloatBinopExpr

#include "soot/grimp/internal/AbstractGrimpFloatBinopExpr.h"

#ifndef _JC_soot_grimp_internal_GMulExpr_H_
#define _JC_soot_grimp_internal_GMulExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GMulExpr$sub_refs	_jc_soot_grimp_internal_GMulExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GMulExpr$sub_nonrefs	_jc_soot_grimp_internal_GMulExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GMulExpr$refs	_jc_soot_grimp_internal_GMulExpr$refs;
typedef struct _jc_soot_grimp_internal_GMulExpr$nonrefs	_jc_soot_grimp_internal_GMulExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GMulExpr$object	_jc_soot_grimp_internal_GMulExpr$object;

typedef const struct _jc_soot_grimp_internal_GMulExpr$vmethods	_jc_soot_grimp_internal_GMulExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GMulExpr$vtable	_jc_soot_grimp_internal_GMulExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GMulExpr$vtype	_jc_soot_grimp_internal_GMulExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GMulExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_grimp_internal_GMulExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GMulExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GMulExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GMulExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GMulExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GMulExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GMulExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GMulExpr$method_info$getSymbol$ce407d9fb7da8b41;

// Virtual methods structure
struct _jc_soot_grimp_internal_GMulExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_grimp_internal_GMulExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GMulExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	soot_jimple_internal_AbstractFloatBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
	_jc_soot_grimp_internal_GMulExpr$vmethods	soot_grimp_internal_GMulExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GMulExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GMulExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GMulExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GMulExpr$refs {
    _jc_soot_grimp_internal_GMulExpr$sub_refs	soot_grimp_internal_GMulExpr;
    _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GMulExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GMulExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpFloatBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpFloatBinopExpr;
    _jc_soot_grimp_internal_GMulExpr$sub_nonrefs	soot_grimp_internal_GMulExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GMulExpr$object {
	_jc_soot_grimp_internal_GMulExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GMulExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GMulExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GMulExpr$vtype _jc_soot_grimp_internal_GMulExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GMulExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GMulExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GMulExpr_H_ */
